You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by mu...@apache.org on 2010/06/23 21:48:32 UTC

svn commit: r957322 - in /myfaces/trinidad/branches/1.2.12.3-branch: trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/ trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/

Author: muthaman
Date: Wed Jun 23 19:48:32 2010
New Revision: 957322

URL: http://svn.apache.org/viewvc?rev=957322&view=rev
Log:
TRINIDAD-1832 - In BlackBerry 4.7, Partial Refreshing an Empty Table Breaks Page Navigation 
TRINIDAD-1831 - Design Time Metadata Missing for a Few Trinidad Components 

Modified:
    myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelCaptionGroup.xml
    myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelRadio.xml
    myfaces/trinidad/branches/1.2.12.3-branch/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/TableRenderer.java

Modified: myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelCaptionGroup.xml
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelCaptionGroup.xml?rev=957322&r1=957321&r2=957322&view=diff
==============================================================================
--- myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelCaptionGroup.xml (original)
+++ myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelCaptionGroup.xml Wed Jun 23 19:48:32 2010
@@ -56,7 +56,9 @@
       <property-name>captionText</property-name>
       <property-class>java.lang.String</property-class>
       <property-extension>
-        <mfp:property-metadata/>
+        <mfp:property-metadata>
+          <mfp:translatable>true</mfp:translatable>
+        </mfp:property-metadata>
         <fmd:property-metadata>
           <fmd:preferred>true</fmd:preferred>
           <fmd:required>false</fmd:required>

Modified: myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelRadio.xml
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelRadio.xml?rev=957322&r1=957321&r2=957322&view=diff
==============================================================================
--- myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelRadio.xml (original)
+++ myfaces/trinidad/branches/1.2.12.3-branch/trinidad-build/src/main/resources/META-INF/maven-faces-plugin/components/trinidad/core/CorePanelRadio.xml Wed Jun 23 19:48:32 2010
@@ -37,7 +37,9 @@
       <property-class>java.lang.String</property-class>
       <suggested-value>{localName} {0}</suggested-value>
       <property-extension>
-        <mfp:property-metadata/>
+        <mfp:property-metadata>
+          <mfp:translatable>true</mfp:translatable>
+        </mfp:property-metadata>
         <fmd:property-metadata>
           <fmd:preferred>true</fmd:preferred>
         </fmd:property-metadata>

Modified: myfaces/trinidad/branches/1.2.12.3-branch/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/TableRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/1.2.12.3-branch/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/TableRenderer.java?rev=957322&r1=957321&r2=957322&view=diff
==============================================================================
--- myfaces/trinidad/branches/1.2.12.3-branch/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/TableRenderer.java (original)
+++ myfaces/trinidad/branches/1.2.12.3-branch/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/TableRenderer.java Wed Jun 23 19:48:32 2010
@@ -406,13 +406,16 @@ abstract public class TableRenderer exte
                  TreeUtils.createNewJSCollectionComponentState(formName, tid)+";", null);
           rw.endElement(XhtmlConstants.SCRIPT_ELEMENT);
           
           // Incases where we partial refresh an empty table, Windows Mobile 
           // ignore the JS which is sent as a PPR response to handle page 
           // navigation and show/hide functions. To fix this problem, lets 
           // render the JS here
-          if (Agent.PLATFORM_PPC.equalsIgnoreCase(
+          if ((Agent.PLATFORM_PPC.equalsIgnoreCase(
                                arc.getAgent().getPlatformName()) 
-               && tContext.getRowData().isEmptyTable())
+              || Agent.PLATFORM_BLACKBERRY.equalsIgnoreCase(
+                               arc.getAgent().getPlatformName()))
+              && supportsScripting(arc) 
+              && tContext.getRowData().isEmptyTable())
           {
             // Script for show/hide funtionality in detailStamp facet
             rw.startElement(XhtmlConstants.SCRIPT_ELEMENT, null);
@@ -406,13 +406,16 @@ abstract public class TableRenderer exte
           rw.endElement(XhtmlConstants.SCRIPT_ELEMENT);
           
-          // Incases where we partial refresh an empty table, Windows Mobile 
-          // ignore the JS which is sent as a PPR response to handle page 
-          // navigation and show/hide functions. To fix this problem, lets 
+          // Incases where we partial refresh an empty table, Windows Mobile/ 
+          // BlackBerry ignore the JS which is sent as a PPR response to handle 
+          // page navigation and show/hide functions. To fix this problem, lets 
           // render the JS here